
DROP DATABASE IF EXISTS qmsdb;
CREATE DATABASE qmsdb CHARACTER SET utf8 COLLATE utf8_general_ci;

USE qmsdb;

CREATE TABLE IF NOT EXISTS products (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `name`          VARCHAR(120) NOT NULL,
  CONSTRAINT UNIQUE (`name`)
) ENGINE = MYISAM ;

CREATE TABLE IF NOT EXISTS groups (
    `id`        BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `pid`       BIGINT NOT NULL,
    `name`      VARCHAR(120) NOT NULL,
    CONSTRAINT UNIQUE (`name`)
) ENGINE = MYISAM ;

CREATE TABLE IF NOT EXISTS groups_10_min_stat (
    `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `group_id`      BIGINT NOT NULL,
    `server_time`   TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `alarm`         BIGINT NOT NULL,
    `active`        BIGINT NOT NULL,
    `all_count`     BIGINT NOT NULL,
    CONSTRAINT FOREIGN KEY (`group_id`) REFERENCES groups(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
    CONSTRAINT UNIQUE (`group_id`, `server_time`),
    KEY `server_time` ( `server_time`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS groups_hour_stat (
    `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `group_id`      BIGINT NOT NULL,
    `server_time`   TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `alarm`         BIGINT NOT NULL,
    `active`        BIGINT NOT NULL,
    `all_count`     BIGINT NOT NULL,
    CONSTRAINT FOREIGN KEY (`group_id`) REFERENCES groups(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
    CONSTRAINT UNIQUE (`group_id`, `server_time`),
    KEY `server_time` ( `server_time`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS groups_4_hours_stat (
    `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `group_id`      BIGINT NOT NULL,
    `server_time`   TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `alarm`         BIGINT NOT NULL,
    `active`        BIGINT NOT NULL,
    `all_count`     BIGINT NOT NULL,
    CONSTRAINT FOREIGN KEY (`group_id`) REFERENCES groups(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
    CONSTRAINT UNIQUE (`group_id`, `server_time`),
    KEY `server_time` ( `server_time`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS groups_day_stat (
    `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `group_id`      BIGINT NOT NULL,
    `server_time`   TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `alarm`         BIGINT NOT NULL,
    `active`        BIGINT NOT NULL,
    `all_count`     BIGINT NOT NULL,
    CONSTRAINT FOREIGN KEY (`group_id`) REFERENCES groups(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
    CONSTRAINT UNIQUE (`group_id`, `server_time`),
    KEY `server_time` ( `server_time`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS groups_4_days_stat (
    `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `group_id`      BIGINT NOT NULL,
    `server_time`   TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `alarm`         BIGINT NOT NULL,
    `active`        BIGINT NOT NULL,
    `all_count`     BIGINT NOT NULL,
    CONSTRAINT FOREIGN KEY (`group_id`) REFERENCES groups(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
    CONSTRAINT UNIQUE (`group_id`, `server_time`),
    KEY `server_time` ( `server_time`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS groups_week_stat (
    `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `group_id`      BIGINT NOT NULL,
    `server_time`   TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `alarm`         BIGINT NOT NULL,
    `active`        BIGINT NOT NULL,
    `all_count`     BIGINT NOT NULL,
    CONSTRAINT FOREIGN KEY (`group_id`) REFERENCES groups(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
    CONSTRAINT UNIQUE (`group_id`, `server_time`),
    KEY `server_time` ( `server_time`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS devices (
  `id`                  BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `mac`                 VARCHAR(64) NOT NULL,
  `serial`              VARCHAR(64) NOT NULL,
  `product_type`        VARCHAR(64) NOT NULL,
  `product_id`          BIGINT NOT NULL,
  `ip`                  VARCHAR(15) NOT NULL,
  `last_session`        TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `last_alarm_session`  TIMESTAMP DEFAULT 0,
  `software_version`    VARCHAR(64) NOT NULL,
  `OUI`                 VARCHAR(64) NOT NULL,
  `hardware_version`    VARCHAR(64) NOT NULL,
  `group_name`          VARCHAR(64) DEFAULT NULL,
  `group_id`            BIGINT DEFAULT NULL,
  CONSTRAINT UNIQUE (`mac`, `serial`),
  KEY `group_id` (`group_id`),
  KEY `combined` (`mac`, `product_type`, `group_name`),
  KEY `combined2` (`product_type`, `group_name`),
  KEY `gr_name` (`group_name`)
) ENGINE = InnoDB;

CREATE TABLE IF NOT EXISTS alarm_devices (
  `id`                BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `dev_id`            BIGINT NOT NULL,
  `counter_id`        BIGINT NOT NULL,
  `server_time`      TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  KEY `combo` (`dev_id`, `counter_id`),
  KEY `server_time` (`server_time`),
  CONSTRAINT FOREIGN KEY (`dev_id`) REFERENCES devices(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT FOREIGN KEY (`counter_id`) REFERENCES counters(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS cast_popularity (
  `id`                    BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `count_time`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `cast_id`               BIGINT NOT NULL,
  `protocol_type`         TINYINT DEFAULT 0,
  `sec_count`             BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`cast_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`cast_id`) REFERENCES casts(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS cast_hour_popularity (
  `id`                    BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `count_time`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `cast_id`               BIGINT NOT NULL,
  `protocol_type`         TINYINT DEFAULT 0,
  `sec_count`             BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`cast_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`cast_id`) REFERENCES casts(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS cast_4_hours_popularity (
  `id`                    BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `count_time`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `cast_id`               BIGINT NOT NULL,
  `protocol_type`         TINYINT DEFAULT 0,
  `sec_count`             BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`cast_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`cast_id`) REFERENCES casts(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS cast_day_popularity (
  `id`                    BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `count_time`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `cast_id`               BIGINT NOT NULL,
  `protocol_type`         TINYINT DEFAULT 0,
  `sec_count`             BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`cast_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`cast_id`) REFERENCES casts(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS cast_4_days_popularity (
  `id`                    BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `count_time`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `cast_id`               BIGINT NOT NULL,
  `protocol_type`         TINYINT DEFAULT 0,
  `sec_count`             BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`cast_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`cast_id`) REFERENCES casts(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS cast_week_popularity (
  `id`                    BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `count_time`            TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `cast_id`               BIGINT NOT NULL,
  `protocol_type`         TINYINT DEFAULT 0,
  `sec_count`             BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`cast_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`cast_id`) REFERENCES casts(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS cast_switch (
  `dev_id`          BIGINT NOT NULL,
  `cast_id`         BIGINT NOT NULL,
  `channel`         INT UNSIGNED NOT NULL,
  `time_start`      DATETIME NOT NULL,
  `time_end`        DATETIME NOT NULL,
  KEY `devices` (`dev_id`, `cast_id`),
  PRIMARY KEY `time_period`(`dev_id`, `time_start`, `channel`)
)ENGINE = MYISAM PARTITION BY HASH( DAYOFYEAR(`time_start`) ) PARTITIONS 366;

CREATE TABLE IF NOT EXISTS counters (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `name`          VARCHAR(120) NOT NULL,
  `product_id`    BIGINT NOT NULL,
  `value_type`    INTEGER NOT NULL,
  `protocol_type` TINYINT DEFAULT 0,
  CONSTRAINT UNIQUE (`name`, `product_id`, `protocol_type`),
  CONSTRAINT FOREIGN KEY (`product_id`) REFERENCES products(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS casts (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `url`           VARCHAR(250) NOT NULL,
  `short_name`    VARCHAR(64) DEFAULT NULL,
  `type`          TINYINT DEFAULT 0,
  CONSTRAINT UNIQUE (`url`, `type`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS filters(
    `id`        BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `ip`        VARCHAR(15) NOT NULL,
    `mask`      VARCHAR(15) NOT NULL,
    `group_id`  BIGINT NOT NULL,
    CONSTRAINT UNIQUE (`ip`, `mask`),
    CONSTRAINT FOREIGN KEY (`group_id`) REFERENCES groups(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS black_list(
    `id`        BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `url`       VARCHAR(120) NOT NULL,
    `type`      TINYINT,
    CONSTRAINT UNIQUE (`url`, `type`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS users(
    `id`                BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
    `username`          VARCHAR(64) NOT NULL,
    `password`          CHAR(32) NOT NULL,
    `view_users`        TINYINT CHECK (view_users = 1 OR view_users = 0),
    `edit_users`        TINYINT CHECK (edit_users = 1 OR edit_users = 0),
    `work_dumps`        TINYINT CHECK (work_dumps = 1 OR work_dumps = 0),
    `view_devices`      TINYINT CHECK (view_devices = 1 OR view_devices = 0),
    `view_casts_mc`     TINYINT CHECK (view_casts_mc = 1 OR view_casts_mc = 0),
    `view_casts_hls`    TINYINT CHECK (view_casts_hls = 1 OR view_casts_hls = 0),
    `view_casts_http`   TINYINT CHECK (view_casts_http = 1 OR view_casts_http = 0),
    `view_casts_rtp`    TINYINT CHECK (view_casts_rtp = 1 OR view_casts_rtp = 0),
    `edit_casts_mc`     TINYINT CHECK (edit_casts_mc = 1 OR edit_casts_mc = 0),
    `edit_casts_hls`    TINYINT CHECK (edit_casts_hls = 1 OR edit_casts_hls = 0),
    `edit_casts_http`   TINYINT CHECK (edit_casts_http = 1 OR edit_casts_http = 0),
    `edit_casts_rtp`    TINYINT CHECK (edit_casts_rtp = 1 OR edit_casts_rtp = 0),
    `view_groups`       TINYINT CHECK (view_groups = 1 OR view_groups = 0),
    `edit_groups`       TINYINT CHECK (edit_groups = 1 OR edit_groups = 0),
    `edit_counters`     TINYINT CHECK (edit_counters = 1 OR edit_counters = 0),
    `view_applications` TINYINT CHECK (view_applications = 1 OR view_applications = 0),
    `edit_applications` TINYINT CHECK (edit_applications = 1 OR edit_applications = 0),
     CONSTRAINT UNIQUE (`username`)
) ENGINE = MYISAM;

INSERT INTO users (`username`, `password`, `view_users`, `edit_users`,`work_dumps`,  `view_devices`,
    `view_casts_mc`, `view_casts_hls`, `edit_casts_mc`, `edit_casts_hls`, `view_groups`, `edit_groups`,
     `edit_counters`, `view_casts_http`, `view_casts_rtp`, `edit_casts_http`, `edit_casts_rtp`,
     `view_applications`, `edit_applications`)
    VALUES ('qmsadmin', MD5('qserver_qmspassword'), 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1);

CREATE TABLE IF NOT EXISTS value_dbl (
  `dev_id`          BIGINT NOT NULL,
  `cast_id`         BIGINT NOT NULL,
  `counter_id`      BIGINT NOT NULL,
  `channel`         INT UNSIGNED NOT NULL,
  `subsystem`       TINYINT DEFAULT 0,
  `time_start`      DATETIME NOT NULL,
  `time_end`        DATETIME NOT NULL,
  `server_time`     DATETIME NOT NULL,
  `value`           DOUBLE NOT NULL,
  KEY `devices` (`dev_id`, `counter_id`),
  KEY `casts` (`cast_id`),
  PRIMARY KEY (`server_time`, `dev_id`, `counter_id`, `cast_id`, `time_start`)
) ENGINE = MYISAM PARTITION BY HASH( DAYOFYEAR(`server_time`) ) PARTITIONS 366;

CREATE TABLE IF NOT EXISTS applications (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `name`          VARCHAR(250) NOT NULL,
  `short_name`    VARCHAR(64) DEFAULT NULL,
  `icon_path`     VARCHAR(120) DEFAULT NULL,
  `app_type`      TINYINT DEFAULT 0,
  CONSTRAINT UNIQUE (`name`, `app_type`)
) ENGINE = MYISAM;


CREATE TABLE IF NOT EXISTS applicationlinks (
  `app_id`              BIGINT NOT NULL,
  `dev_id`              BIGINT NOT NULL,
  `last_active_time`    TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  CONSTRAINT UNIQUE (`app_id`, `dev_id`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT FOREIGN KEY (`dev_id`) REFERENCES devices(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applicationgrowth (
  `app_id`              BIGINT NOT NULL,
  `dev_count`           BIGINT NOT NULL,
  `period`              VARCHAR(64) NOT NULL,
  `date_from`           TIMESTAMP NOT NULL,
  `date_to`             TIMESTAMP NOT NULL,
  CONSTRAINT UNIQUE (`app_id`, `period`, `date_from`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applications_hour_rating (
  `app_id`              BIGINT NOT NULL,
  `count_time`          TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `sec_count`           BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`app_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applications_6hours_rating (
  `app_id`              BIGINT NOT NULL,
  `count_time`          TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `sec_count`           BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`app_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applications_day_rating (
   `app_id`              BIGINT NOT NULL,
   `count_time`          TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `sec_count`           BIGINT NOT NULL,
   KEY `count_time` (`count_time`),
   CONSTRAINT UNIQUE (`app_id`, `count_time`),
   CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applications_15days_rating (
  `app_id`              BIGINT NOT NULL,
  `count_time`          TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `sec_count`           BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`app_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

COMMIT;

SHOW TABLES IN qmsdb;
