/* default storage engine for all tables */
SET storage_engine = InnoDB;

DROP DATABASE IF EXISTS qmsdb;
CREATE DATABASE qmsdb CHARACTER SET utf8 COLLATE utf8_general_ci;

USE qmsdb;

CREATE TABLE IF NOT EXISTS products (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `name`          VARCHAR(120) NOT NULL,
  CONSTRAINT UNIQUE (`name`)
);

CREATE TABLE IF NOT EXISTS devices (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `serial`        VARCHAR(64) NOT NULL,
  `product_id`    BIGINT NOT NULL,
  CONSTRAINT UNIQUE (`serial`, `product_id`),
  CONSTRAINT FOREIGN KEY (`product_id`) REFERENCES products(`id`)
  ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE IF NOT EXISTS counters (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `name`          VARCHAR(120) NOT NULL,
  `product_id`    BIGINT NOT NULL,
  `type`          INTEGER NOT NULL,
  CONSTRAINT UNIQUE (`name`, `product_id`),
  CONSTRAINT FOREIGN KEY (`product_id`) REFERENCES products(`id`)
  ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE IF NOT EXISTS casts (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `url`           VARCHAR(250) NOT NULL,
  `short_name`    VARCHAR(64) DEFAULT NULL,
  CONSTRAINT UNIQUE (`url`)
);

/* table pattern

CREATE TABLE IF NOT EXISTS sessions_MMDD (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `dev_id`        BIGINT NOT NULL,
  `reg_time`      TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `dev_info`      TEXT NOT NULL,
  CONSTRAINT FOREIGN KEY (`dev_id`) REFERENCES devices(`id`)
  ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE IF NOT EXISTS value_str_MMDD (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `dev_id`        BIGINT NOT NULL,
  `ses_id`        BIGINT NOT NULL,
  `cast_id`       BIGINT DEFAULT NULL,
  `counter_id`    BIGINT NOT NULL,
  `channel`       VARCHAR(64) DEFAULT NULL,
  `time_start`    TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `time_end`      TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00:00',
  `value`         TEXT NOT NULL
);

CREATE TABLE IF NOT EXISTS value_long_MMDD (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `dev_id`        BIGINT NOT NULL,
  `ses_id`        BIGINT NOT NULL,
  `cast_id`       BIGINT DEFAULT NULL,
  `counter_id`    BIGINT NOT NULL,
  `channel`       VARCHAR(64) DEFAULT NULL,
  `time_start`    TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `time_end`      TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00:00',
  `value`         BIGINT NOT NULL
);

CREATE TABLE IF NOT EXISTS value_dbl_MMDD (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `dev_id`        BIGINT NOT NULL,
  `ses_id`        BIGINT NOT NULL,
  `cast_id`       BIGINT DEFAULT NULL,
  `counter_id`    BIGINT NOT NULL,
  `channel`       VARCHAR(64) DEFAULT NULL,
  `time_start`    TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `time_end`      TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00:00',
  `value`         DOUBLE NOT NULL
);

*/

COMMIT;

SHOW TABLES IN qmsdb;
