USE qmsdb;

DROP TABLE IF EXISTS applications;
DROP TABLE IF EXISTS applications_rating;

CREATE TABLE IF NOT EXISTS applications (
  `id`            BIGINT PRIMARY KEY AUTO_INCREMENT NOT NULL,
  `name`          VARCHAR(250) NOT NULL,
  `short_name`    VARCHAR(64) DEFAULT NULL,
  `icon_path`     VARCHAR(120) DEFAULT NULL,
  `app_type`      TINYINT DEFAULT 0,
  CONSTRAINT UNIQUE (`name`, `app_type`)
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applicationlinks (
  `app_id`              BIGINT NOT NULL,
  `dev_id`              BIGINT NOT NULL,
  `last_active_time`    TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  CONSTRAINT UNIQUE (`app_id`, `dev_id`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT FOREIGN KEY (`dev_id`) REFERENCES devices(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applicationgrowth (
  `app_id`              BIGINT NOT NULL,
  `dev_count`           BIGINT NOT NULL,
  `period`              VARCHAR(64) NOT NULL,
  `date_from`           TIMESTAMP NOT NULL,
  `date_to`             TIMESTAMP NOT NULL,
  CONSTRAINT UNIQUE (`app_id`, `period`, `date_from`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applications_hour_rating (
  `app_id`              BIGINT NOT NULL,
  `count_time`          TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `sec_count`           BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`app_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applications_6hours_rating (
  `app_id`              BIGINT NOT NULL,
  `count_time`          TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `sec_count`           BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`app_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applications_day_rating (
   `app_id`              BIGINT NOT NULL,
   `count_time`          TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `sec_count`           BIGINT NOT NULL,
   KEY `count_time` (`count_time`),
   CONSTRAINT UNIQUE (`app_id`, `count_time`),
   CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

CREATE TABLE IF NOT EXISTS applications_15days_rating (
  `app_id`              BIGINT NOT NULL,
  `count_time`          TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `sec_count`           BIGINT NOT NULL,
  KEY `count_time` (`count_time`),
  CONSTRAINT UNIQUE (`app_id`, `count_time`),
  CONSTRAINT FOREIGN KEY (`app_id`) REFERENCES applications(`id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE = MYISAM;

ALTER TABLE users       ADD COLUMN `view_applications`  TINYINT CHECK (view_applications = 1 OR view_applications = 0),
                        ADD COLUMN `edit_applications`  TINYINT CHECK (edit_applications = 1 OR edit_applications = 0);