/**
 * Файл для страницы groups.html
 * Инициализация дерева групп, инициализация таблицы устройств
 */
 //Создает дерево групп
function createDynaTree() {
	// --- Initialize first Dynatree -------------------------------------------
	jQuery("#available_groups").dynatree({
		initAjax: {
			url: "./groups/availableGroups",
			data: {"groupid": "0" // Optional arguments to append to the url
                },
            error: errorJsonDyna
		},
		onLazyRead: function(node){
			// Mockup a slow reqeuest ...
			node.appendAjax({
				url: "./groups/availableGroups",
				data: {"groupid": node.data.key // Optional arguments to append to the url
                   	},
                   	error: errorJsonDyna
	    		//debugLazyDelay: 750 // don't do this in production code
			});
		},
		dnd: {
			onDragStart: function(node) {
				/** This function MUST be defined to enable dragging for the tree.
				*  Return false to cancel dragging of node.
				*/
				logMsg("tree.onDragStart(%o)", node);
				return true;
			},
			onDragStop: function(node) {
				// This function is optional.
				logMsg("tree.onDragStop(%o)", node);
			},
			autoExpandMS: 1000,
			preventVoidMoves: true, // Prevent dropping nodes 'before self', etc.
			onDragEnter: function(node, sourceNode) {
				/** sourceNode may be null for non-dynatree droppables.
				*  Return false to disallow dropping on node. In this case
				*  onDragOver and onDragLeave are not called.
				*  Return 'over', 'before, or 'after' to force a hitMode.
				*  Return ['before', 'after'] to restrict available hitModes.
				*  Any other return value will calc the hitMode from the cursor position.
				*/
				logMsg("tree.onDragEnter(%o, %o)", node, sourceNode);
				return true;
			},
			onDragOver: function(node, sourceNode, hitMode) {
				/** Return false to disallow dropping this node.
				*
				*/
				logMsg("tree.onDragOver(%o, %o, %o)", node, sourceNode, hitMode);
				// Prevent dropping a parent below it's own child
				if(node.isDescendantOf(sourceNode)){
					return false;
				}
				// Prohibit creating childs in non-folders (only sorting allowed)
				if( !node.data.isFolder && hitMode === "over" ){
					return "after";
				}
			},
		    onDrop: function(node, sourceNode, hitMode, ui, draggable) {
				/** This function MUST be defined to enable dropping of items on
				* the tree.
				*/
				logMsg("tree.onDrop(%o, %o, %s)", node, sourceNode, hitMode);
				//get text error area and break old text
				var resp = document.getElementById('error_text');
				resp.innerHTML ="";
				//create link
				var href = "groupid="+sourceNode.data.key;
				href += "&parent="+node.data.key;
				href += "&hitMode="+hitMode;
				//create a request
				var myRequest = new Request({
    				url: './groups/swap',
    				method: 'get',
    				onSuccess: function(responseText){
    					if (responseText.search('OK')>-1){
    					    sourceNode.move(node, hitMode);
    					} else {
        					resp.innerHTML = "<font color='red' size='2'>" + responseText + "</font>";
						}
    				},
    				onFailure: function( xhr ){
        				resp.innerHTML = "<font color='red' size='2'>Ошибка связи с сервером...</font>";
        				errorJson( xhr );
    				}
				});
				//send request
				myRequest.send(href);
				// expand the drop target
				//        sourceNode.expand(true);
			},
			onDragLeave: function(node, sourceNode) {
				/** Always called if onDragEnter was called.
				*/
				logMsg("tree.onDragLeave(%o, %o)", node, sourceNode);
			}
		},
		onDblClick: function(node, event) {
    		editNode(node);
    		return false;
    	},
    	checkbox: true,
		onActivate: function(node) {
           	// A DynaTreeNode object is passed to the activation handler
           	// Note: we also get this event, if persistence is on, and the page is reloaded.
           	reloadDevGrid( node.data.key );
       	},
       	selectMode: 1,
       	clickFolderMode: 1
	});
};
//Создает таблицу устройств
function createDeviceGrid(){
    jQuery("#available_devices").jqGrid({
        url: window.location.pathname + '/availableDevices?groupid=0' ,
     	datatype: "json",
        height: 500,
        width: 900,
        colNames:['MAC', 'C/H', 'Тип', 'IP', 'Группа'],
        colModel:[
           	{name:'mac',index:'mac', width:240, sortable:false, searchoptions:{sopt:['eq','ne']} },
           	{name:'serial',index:'serial', width:240, sortable:false, searchoptions:{sopt:['eq','ne']}},
           	{name:'product_type',index:'product_type', width:240, sorttype:'string', searchoptions:{sopt:['eq','ne']} },
           	{name:'ip',index:'ip', width:240, sortable:false, searchoptions:{sopt:['eq','ne']}},
           	{name:'group_name',index:'group_name', width:240, sorttype:'string', stype:'select',
           	            searchoptions:{ sopt:['eq'], value: ":Для текущей группы;*:Для всех" }}
        ],
        rowNum:30,
        rowList:[30,50,100],
        mtype: "GET",
        multiSort: true,
        loadError : errorJsonData,
        //    shrinkToFit :false,
        pager: '#pavailable_devices',
        sortname: 'last_session',
        viewrecords: true,
        sortorder: "desc",
        multiselect:true,
        caption:"Список устройств"
    });
    jQuery("#available_devices").jqGrid('navGrid','#pavailable_devices',{del:false,add:false,edit:false},{},{},{},{multipleSearch:true});
    jQuery("#insertbut").click( function() {
    	var s;
    	s = jQuery("#available_devices").jqGrid('getGridParam','selarrrow');
    	insertInGroup( s );
    });
    jQuery("#delbut").click( function() {
    	var s;
        s = jQuery("#available_devices").jqGrid('getGridParam','selarrrow');
        deleteFromGroups( s );
    });
};
//При загрузке построить дерево групп и таблицу устройств
function createJquery(){
    createDeviceGrid();
    createDynaTree()
};

window.onload = createJquery;